
# Oyna 💃🏻🕺🏻💃🏿🕺🏿💃🕺

## Welcome to the **Oyna** repository! 🎮

This repository is dedicated to showcasing a collection of simple and fun computer games, all implemented in Python. The main goal of **Oyna** is to provide a platform where anyone, can explore Python programming through engaging and interactive games. By studying and interacting with these games, you can learn important programming concepts, algorithms, and the Python language in an enjoyable and hands-on way.

Whether you're just starting with Python or looking to improve your coding skills, the **Oyna** repository is a great resource to help you learn while having fun.

## What You'll Find Here
This repository contains various games that highlight different aspects of Python programming. Each game is designed to be simple yet effective, and they are all easy to understand and modify.




<table>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/sudoku/"> Sudoku </a> </br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/sudoku.png" alt="Sudoku" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/twenty_forty_eight_2048/">2048</a> </br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/2048.png" alt="2048" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/matching/">Matching</a> </br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/matching.png" alt="Matching" width=200/> </td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/minesweeper/"> Minesweeper </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/minesweeper.png" alt="Minesweeper" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/find_difference/">Find Difference </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/find_difference.png" alt="Find Difference" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/maze/"> Maze</a> </br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/maze.png" alt="Maze" width=200/> </td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/chimp/"> Chimp </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/chimp.png" alt="Chimp" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/snake/"> Snake </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/snake.png" alt="Snake" width=200/> </td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/chutes_and_ladders/"> Chutes and Ladders </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/chutes_and_ladders.png" alt="Chutes and Ladders" width=200/> </td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/dino/"> Dino or Dinosaur Game </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/dino.png" alt="Dino" width=200/></td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/bubble_shooter/"> Bubble Shooter </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/bubble_shooter.png" alt="Bubble Shooter" width=200/></td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/flappy_bird/"> Flappy Bird </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/flappy_birds.png" alt="Flappy Bird" width=200/> </td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/falling_tower/"> Falling Tower </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/falling_tower.png" alt="Falling Tower" width=200/></td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/shoot_colors/"> Shoot Colors </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/shoot_colors.png" alt="Shoot Colors" width=200/></td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/reversi/"> Reversi </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/reversi.png" alt="reversi" width=200/>
      </td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/supermario_pixel/"> SuperMario Pixel </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/supermario_pixel.png" alt="SuperMario Pixel" width=200/></td>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/tetris/"> Tetris </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/tetris.png" alt="Tetris" width=200/>
      </td>
      </td><td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/tik_tok_toe/"> Tik Tok Toe </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/tiktoktoe.png" alt="Tik Tok Toe" width=200/></td>
   </tr>
   <tr>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/reverse_slide_puzzle/"> Reverse Slide Puzzle </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/reverse_slide_puzzle.png" alt="Reverse Slide Puzzle" width=200/>
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/checkers/"> Checkers </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/checkers.png" alt="Checkers" width=200 />
      <td><a href="https://github.com/kamyarmg/oyna/tree/main/src/oyna/explosion/">UFO Explosion </a></br><img src="https://raw.githubusercontent.com/kamyarmg/oyna/refs/heads/main/docs/images/explosion.png" alt="UFO Explosion" width=200/></td>

   </tr>

</table>

## Why Oyna?
- **Beginner-Friendly**: Whether you're new to Python or programming in general, these games are designed to be easy to follow.
- **Learn by Doing**: The best way to learn programming is through practice, and **Oyna** offers you an opportunity to get hands-on experience by working with real code.
- **Fun and Engaging**: Who said learning can't be fun? These games are built to keep you engaged and motivated while learning Python.

## How to Use
1. Clone this repository to your local machine using:
   ```bash
   git clone https://github.com/kamyarmg/oyna.git
   ```
   **OR** Install it using pip
   ```bash
   pip install oyna
   ```
2. Navigate to the game directory you want to explore.
3. Run the game using Python
4. Enjoy and start learning!

---
To add or refactor a game or any other feature, please read the [CONTRIBUTING.md](https://github.com/kamyarmg/oyna/tree/main/CONTRIBUTING.md) file first. After that, you can create a new game or make changes and submit a pull request.
